==> ydk-models-ietf-0.1.4.tar.gz: ydk-models-ietf-0.1.4/ydk/models/ietf/ietf_diffserv_action.py <==
""" ietf_diffserv_action 

This module contains a collection of YANG definitions for configuring
diffserv specification implementations. Copyright (c) 2014 IETF
Trust and the persons identified as authors of the code. All rights
reserved. Redistribution and use in source and binary forms, with
or without modification, is permitted pursuant to, and subject
to the license terms contained in, the Simplified BSD License
set forth in Section 4.c of the IETF Trust's Legal Provisions
Relating to IETF Documents (http\://trustee.ietf.org/license\-info).
This version of this YANG module is part of RFC XXXX; see the
RFC itself for full legal notices.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class AlgorithmicDrop(Identity):
    """
    algorithmic\-drop action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(AlgorithmicDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:algorithmic-drop")


class DropType(Identity):
    """
    drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(DropType, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:drop-type")


class Marking(Identity):
    """
    marking action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Marking, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:marking")


class MaxRate(Identity):
    """
    max\-rate action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MaxRate, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:max-rate")


class Meter(Identity):
    """
    meter action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Meter, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter")


class MeterActionType(Identity):
    """
    action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionType, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-type")


class MinRate(Identity):
    """
    min\-rate action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MinRate, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:min-rate")


class Priority(Identity):
    """
    priority action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Priority, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:priority")


class AlwaysDrop(Identity):
    """
    always drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(AlwaysDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:always-drop")


class MeterActionDrop(Identity):
    """
    drop action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-drop")


class MeterActionSet(Identity):
    """
    mark action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionSet, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-set")


class RandomDetect(Identity):
    """
    random detect algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(RandomDetect, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:random-detect")


class TailDrop(Identity):
    """
    tail drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(TailDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:tail-drop")

==> ydk-models-ietf-0.1.5.post1.tar.gz: ydk-models-ietf-0.1.5.post1/ydk/models/ietf/ietf_diffserv_action.py <==
""" ietf_diffserv_action 

This module contains a collection of YANG definitions for configuring
diffserv specification implementations. Copyright (c) 2014 IETF
Trust and the persons identified as authors of the code. All rights
reserved. Redistribution and use in source and binary forms, with
or without modification, is permitted pursuant to, and subject
to the license terms contained in, the Simplified BSD License
set forth in Section 4.c of the IETF Trust's Legal Provisions
Relating to IETF Documents (http\://trustee.ietf.org/license\-info).
This version of this YANG module is part of RFC XXXX; see the
RFC itself for full legal notices.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class Marking(Identity):
    """
    marking action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Marking, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:marking")


class DropType(Identity):
    """
    drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(DropType, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:drop-type")


class MinRate(Identity):
    """
    min\-rate action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MinRate, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:min-rate")


class Meter(Identity):
    """
    meter action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Meter, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter")


class Priority(Identity):
    """
    priority action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(Priority, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:priority")


class MaxRate(Identity):
    """
    max\-rate action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MaxRate, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:max-rate")


class MeterActionType(Identity):
    """
    action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionType, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-type")


class AlgorithmicDrop(Identity):
    """
    algorithmic\-drop action type
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(AlgorithmicDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:algorithmic-drop")


class AlwaysDrop(Identity):
    """
    always drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(AlwaysDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:always-drop")


class TailDrop(Identity):
    """
    tail drop algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(TailDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:tail-drop")


class MeterActionDrop(Identity):
    """
    drop action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionDrop, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-drop")


class MeterActionSet(Identity):
    """
    mark action type in a meter
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(MeterActionSet, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:meter-action-set")


class RandomDetect(Identity):
    """
    random detect algorithm
    
    

    """

    _prefix = 'action'
    _revision = '2015-04-07'

    def __init__(self):
        super(RandomDetect, self).__init__("urn:ietf:params:xml:ns:yang:ietf-diffserv-action", "ietf-diffserv-action", "ietf-diffserv-action:random-detect")
